#
# spec file for package python-pyroma
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pyroma
Version:        4.2
Release:        1.3
Summary:        Test a Python project's adherence to packaging guidelines
License:        MIT
URL:            https://github.com/regebro/pyroma
Source:         https://files.pythonhosted.org/packages/source/p/pyroma/pyroma-%{version}.tar.gz
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module build >= 0.7}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module trove-classifiers >= 2022.6}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pygments
Requires:       python-build >= 0.7
Requires:       python-docutils
Requires:       python-packaging
Requires:       python-requests
Requires:       python-setuptools >= 42
Requires:       python-trove-classifiers >= 2022.6
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Pyroma is a package that gives a rating of how well a Python project
complies with the best practices of the Python packaging ecosystem,
primarily PyPI, pip, Distribute, etc., as well as a list of issues
that could be improved.

It's written so that there are a library with methods to call from Python, as
well as a script, also called pyroma.

%prep
%setup -q -n pyroma-%{version}

%build
export LANG=en_US.UTF-8
%pyproject_wheel

%install
export LANG=en_US.UTF-8
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pyroma
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
# Requires network
%pytest -k 'not (test_complete or test_distribute)'

%post
%python_install_alternative pyroma

%postun
%python_uninstall_alternative pyroma

%files %{python_files}
%license LICENSE.txt
%doc README.rst CHANGES.txt
%python_alternative %{_bindir}/pyroma
%{python_sitelib}/pyroma
%{python_sitelib}/pyroma-%{version}.dist-info

%changelog
* Mon Mar 25 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.2:
  * Fall back to installing project's build backend in an isolated
    environment if a compatible version isn't installed in the current env
  * Fix metadata extraction failure when project ``long_description`` is
    included as a header rather than a payload in the ``METADTA`` file
  * Add a fallback to restore compatibility with Setuptools <61
  * Add ``python_requires``, update classifiers, add implicit dependencies
    and remove unused deps in Pyroma's own packaging metadata
  * Moved from a custom trove classifiers list to using the
    trove-classifiers package
  * Support checking the Requires-Python metadata
  * Silence noisy build backend output when building metadata
  * Official support for Python 3.11
  * Some string formatting bugs
  * Now follows black and flake8 rules
  * Check if author_email field contains author name
  * The deprecation test for test_suite is no longer needed, as the patched
    setuptools method of gathering metadata as a whole is deprecated.
  * `description_content_type` also needs a mapping in the metadata map.
  * Added support for PEP517 by using `build` to build the metadata as a
    preferred build method over the old patched setuptools method.
  * Add a deprecation for `test_suite`
  * Fixed __getattr__-related crash in tests with python3.7
  * Added support for pre-commit
  * Rewrote parts of the PyPI support, to avoid using the xmlrpc API,
    since it's being heavily rate-limited at the moment. Only one call
    is using it now, which seems to work fine.
  * Backwards incompatible change: As a result of the above change, when
    looking for packages on PyPI, the package name must now be spelled
    exactly correct, including capitalization.
  * Added --quiet option to output only the rating
  * Pyroma is now an executable module, and can be called with
    `python -m pyroma`
- Switch to pyproject and pytest macros.
- No more greedy globs in %%files.
- Remove a few unneeded words from the Summary.
* Fri May 28 2021 pgajdos@suse.com
- version update to 3.1
  - Added correct detection of setup.py encoding
  - Code cleanup [CAM Gerlach]
  - Drop support for Python 2 [Florian Bruhin]
  - Add back official support for Python 3.6, I didn't realize it was still officially supported
  - Update to the current list of Trove classifiers.
  - Officially support Python 3.8 and 3.9
  - Drop official support for Python 3.5 and 3.6 (still works though).
- %%check: use %%pytestunit rpm macro
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Mar 20 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 2.6
  * Ran flake8 and black on the code, better formatting for
    classifiers.py generation.
  * Support for PEP 517, setup.cfg-only packages. [Max Tyulin]
  * Adds support for Markdown long_descriptions, if you set
    long_description_content_type to 'text/markdown'
  * Installs Pygments to avoid an error message of you have
    syntax highlighted code in the long_description.
* Mon Jun  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.5:
  - Fixed #35: Correctly restore ``sys.argv``.  [maurits]
  - Added back the BusFactor test, the XMLRPC API supports it.
  - #26: Adding a test to check for a development status classifier.
  - #21: Accept the new project_urls distribution data.
  - Now verifies that classifiers are valid, and that the license field
    and license classifiers match.
  - The rating now again reflects if the long_description isn't valid ReST.
  - #38: Recommendations for the License field has changed.
* Tue Feb 12 2019 Jan Engelhardt <jengelh@inai.de>
- Trim rhetoric storytelling from descriptions.
* Tue Feb 12 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v2.4
  - Get rid of the tests that rely on HTML scraping, it's too brittle.
  - Added -n command line option to set the minimum rating needed for pyroma
    to return success, useful in scripts.
- from 2.3.1
  - Fixed installation fails with a non-UTF8 locale under Python 3.
- Remove unnecessary build dependency on python-devel
- Update URL from BitBucket to GitHub
- Use %%license
- Fix %%doc to use README.rst instead of empty README.txt
* Thu Nov 16 2017 toddrme2178@gmail.com
- Initial version for v2.3
